@@ -1,5 +1,6 @@
-`cart2clock` <-
-function(x, y = NULL, circle)
+### cart2clock.R
+
+cart2clock <- function(x, y = NULL, circle)
   ## Author: Rene Locher
   ## Version: 2005-10-05
   ##
@@ -14,4 +15,3 @@ function(x, y = NULL, circle)
   phi <-(atan(x/y)/2/pi*circle + ifelse(y>0,circle,1.5*circle))%%circle
   return(data.frame(rho=sqrt(x*x+y*y),phi=phi))
 } ## cart2clock
-
